Dependencies class

Constructors

Dependencies()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

base64ToImage(String base64Image, String path) Future<File>
binaryToDecimal(String s) List<int>
calculateHash(String hashValues) String
hexToBin(String s) String
imageToBase64(String imagePath) Future<String>
intToBinary(int pixel) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited